@@ -20,10 +20,12 @@ from tianshou.policy.modelfree.sac import SACPolicy
 from tianshou.policy.modelfree.discrete_sac import DiscreteSACPolicy
 from tianshou.policy.imitation.base import ImitationPolicy
 from tianshou.policy.imitation.bcq import BCQPolicy
+from tianshou.policy.imitation.cql import CQLPolicy
 from tianshou.policy.imitation.discrete_bcq import DiscreteBCQPolicy
 from tianshou.policy.imitation.discrete_cql import DiscreteCQLPolicy
 from tianshou.policy.imitation.discrete_crr import DiscreteCRRPolicy
 from tianshou.policy.modelbased.psrl import PSRLPolicy
+from tianshou.policy.modelbased.icm import ICMPolicy
 from tianshou.policy.multiagent.mapolicy import MultiAgentPolicyManager
 
 __all__ = [
@@ -46,9 +48,11 @@ __all__ = [
     "DiscreteSACPolicy",
     "ImitationPolicy",
     "BCQPolicy",
+    "CQLPolicy",
     "DiscreteBCQPolicy",
     "DiscreteCQLPolicy",
     "DiscreteCRRPolicy",
     "PSRLPolicy",
+    "ICMPolicy",
     "MultiAgentPolicyManager",
 ]
