@@ -98,6 +98,12 @@ class BasePolicy(ABC, nn.Module):
         """
         return act
 
+    def soft_update(self, tgt: nn.Module, src: nn.Module, tau: float) -> None:
+        """Softly update the parameters of target module towards the parameters \
+        of source module."""
+        for tgt_param, src_param in zip(tgt.parameters(), src.parameters()):
+            tgt_param.data.copy_(tau * src_param.data + (1 - tau) * tgt_param.data)
+
     @abstractmethod
     def forward(
         self,
@@ -387,10 +393,10 @@ def _gae_return(
 ) -> np.ndarray:
     returns = np.zeros(rew.shape)
     delta = rew + v_s_ * gamma - v_s
-    m = (1.0 - end_flag) * (gamma * gae_lambda)
+    discount = (1.0 - end_flag) * (gamma * gae_lambda)
     gae = 0.0
     for i in range(len(rew) - 1, -1, -1):
-        gae = delta[i] + m[i] * gae
+        gae = delta[i] + discount[i] * gae
         returns[i] = gae
     return returns
 
