@@ -1,12 +1,16 @@
+"""Trainer package."""
+
+# isort:skip_file
+
 from tianshou.trainer.utils import test_episode, gather_info
 from tianshou.trainer.onpolicy import onpolicy_trainer
 from tianshou.trainer.offpolicy import offpolicy_trainer
 from tianshou.trainer.offline import offline_trainer
 
 __all__ = [
-    "gather_info",
-    "test_episode",
-    "onpolicy_trainer",
     "offpolicy_trainer",
+    "onpolicy_trainer",
     "offline_trainer",
+    "test_episode",
+    "gather_info",
 ]
